#include "wobulation.h"
#ifdef USE_DELAYED_SHIFT
#include "mtimer.h"
#endif

void Wobulation::slotRunBtnClicked()
{
	m_nRunMode = ui.tabWidget->currentIndex();

	if(ui.runBtn->text() == tr("RUN"))	// RUN
	{
		if(m_nRunMode == 0)
		{
			if(checkMode1Settings() == false) return;

			ui.tabWidget->setEnabled(false);
			ui.runBtn->setText(tr("STOP"));

			// turn UV on
			m_pLC8Ctrl->shutterOpen();
		}
		else if(m_nRunMode == 1)
		{
			if(checkMode2Settings() == false) return;

			ui.tabWidget->setEnabled(false);
			ui.runBtn->setText(tr("STOP"));

			// turn UV on
			m_pLC8Ctrl->shutterOpen();
		}
	}
	else	// STOP
	{
		// turn UV off
		m_pLC8Ctrl->shutterClose();

		// clear DMD
		m_pDDC1100->clear();

		ui.tabWidget->setEnabled(true);
		ui.runBtn->setText(tr("RUN"));
	}
}

void Wobulation::slotUVShutterOpened()
{
	if(m_nRunMode == 0)
	{
		m_nCurListIndex = 0;
		m_nCurListRepeatNum = 0;
	}
	else if(m_nRunMode == 1)
	{
		m_nCurCycle = 0;
		m_nCurDurationSequence = 1;
		m_nBufNumIndex = 1;

		// set current position as the origin
		m_pTango->SetPos(0.0, 0.0, 0.0, 0.0);

		// load mask1
#ifdef USE_WLP_DMD
		QStringList fileList;
		fileList.append(m_strFileNameMask1);
		fileList.append(m_strFileNameMask2);

		m_pDDC1100->loadFiles(fileList, (ui.maskNSFlip)->isChecked(), (ui.maskWEFlip)->isChecked());
		m_pDDC1100->startDMD();
		m_pDDC1100->trigger(m_nDurationMask1);
#else
		m_pDDC1100->loadToDMD(m_nBufNumMask1, m_nDurationMask1);
#endif
	}
}


void Wobulation::slotDMDCleared()
#ifdef USE_DELAYED_SHIFT
{
	if(m_nShiftDelay > 0) MTimer::singleShot(m_nShiftDelay, this, SLOT(slotDelayedShiftTimeExpired()));
	else MTimer::singleShot(0, this, SLOT(slotDelayedShiftTimeExpired()));
}

void Wobulation::slotDelayedShiftTimeExpired()
#endif
{
	if(m_nRunMode == 0)
	{

	}
	else if(m_nRunMode == 1)
	{
		if(m_nCurCycle >= m_nCycle) // 1 cycle is completed
		{
			if(m_bDurationSequenceChecked && m_nCurDurationSequence<m_nDurationSequence) // run next duration sequence
			{
				m_nCurCycle = 0;
				m_nBufNumIndex = 1;
				m_nCurDurationSequence++;

				double dx = (double)m_nInterSequenceShiftX / 1000000;
				double dy = (double)m_nInterSequenceShiftY / 1000000;

				m_nDurationMask1 += m_nDurationSequenceStep;
				m_nDurationMask2 -= m_nDurationSequenceStep;

				// move to next sequence position & load mask1
				m_pTango->MoveRel(-dx, -dy, 0, 0, true);

#ifdef USE_WLP_DMD
				m_pDDC1100->trigger(m_nDurationMask1);
#else
				m_pDDC1100->loadToDMD(m_nBufNumMask1, m_nDurationMask1);
#endif
			}
			else
			{
				// turn UV off
				m_pLC8Ctrl->shutterClose();

				// move to the origin
				m_pTango->MoveAbs(0, 0, 0, 0, true);

				ui.tabWidget->setEnabled(true);
				ui.runBtn->setText(tr("RUN"));

#ifdef USE_WLP_DMD
				m_pDDC1100->stopDMD();
#endif
			}
		}
		else
		{
			double dx = (double)m_nShiftX / 1000000;
			double dy = (double)m_nShiftY / 1000000;
			
			if(m_nBufNumIndex == 1)	
			{
				m_nCurCycle++;
				m_nBufNumIndex = 2;

				// move to mask2 position & load mask2
				m_pTango->MoveRel(-dx, -dy, 0, 0, true);

#ifdef USE_WLP_DMD
				m_pDDC1100->trigger(m_nDurationMask2);
#else
				m_pDDC1100->loadToDMD(m_nBufNumMask2, m_nDurationMask2);
#endif
			}
			else
			{
				m_nBufNumIndex = 1;

				// move to mask1 position & load mask1
				m_pTango->MoveRel(dx, dy, 0, 0, true);

#ifdef USE_WLP_DMD
				m_pDDC1100->trigger(m_nDurationMask1);
#else
				m_pDDC1100->loadToDMD(m_nBufNumMask1, m_nDurationMask1);
#endif
			}
		}
	}

}

